=============
django-resume
=============

.. image:: https://img.shields.io/readthedocs/django-resume?style=for-the-badge
   :target: https://django-resume.readthedocs.io/en/latest/

.. image:: https://img.shields.io/pypi/v/django-resume.svg?style=for-the-badge
   :target: https://pypi.org/project/django-resume/

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=for-the-badge
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit

A pluggable framework for managing your resume in Django.

Watch the Talk
--------------

For a quick introduction, you can watch the video on YouTube. 🍿

.. image:: images/skip-the-overhead-preview.png
   :alt: Watch the Talk
   :target: https://fosdem.org/2025/schedule/event/fosdem-2025-6174-skip-the-overhead-lean-web-development-with-django/

Documentation
-------------

Please see https://django-resume.readthedocs.io/ .

CV Preview
----------

Click the image to view the complete, interactive CV on my website.

.. image:: images/wersdoerfer-de-resume-queen-cleo-cv.png
   :alt: Preview of the CV
   :target: https://wersdoerfer.de/resume/queen-cleo/cv/

Resume Preview
--------------

Click the image to view the complete, interactive resume on my website.

.. image:: images/wersdoerfer-de-resume-queen-cleo-cover.png
   :alt: Preview of the Resume
   :target: https://wersdoerfer.de/resume/queen-cleo/
